==> esp8266-0.3.0.crate: esp8266-0.3.0/src/uart0/uart_id.rs <==
#[doc = "Register `UART_ID` reader"]
pub struct R(crate::R<UART_ID_SPEC>);
impl core::ops::Deref for R {
    type Target = crate::R<UART_ID_SPEC>;
    #[inline(always)]
    fn deref(&self) -> &Self::Target {
        &self.0
    }
}
impl core::convert::From<crate::R<UART_ID_SPEC>> for R {
    fn from(reader: crate::R<UART_ID_SPEC>) -> Self {
        R(reader)
    }
}
#[doc = "Register `UART_ID` writer"]
pub struct W(crate::W<UART_ID_SPEC>);
impl core::ops::Deref for W {
    type Target = crate::W<UART_ID_SPEC>;
    #[inline(always)]
    fn deref(&self) -> &Self::Target {
        &self.0
    }
}
impl core::ops::DerefMut for W {
    #[inline(always)]
    fn deref_mut(&mut self) -> &mut Self::Target {
        &mut self.0
    }
}
impl core::convert::From<crate::W<UART_ID_SPEC>> for W {
    fn from(writer: crate::W<UART_ID_SPEC>) -> Self {
        W(writer)
    }
}
#[doc = "Field `uart_id` reader - "]
pub struct UART_ID_R(crate::FieldReader<u32, u32>);
impl UART_ID_R {
    pub(crate) fn new(bits: u32) -> Self {
        UART_ID_R(crate::FieldReader::new(bits))
    }
}
impl core::ops::Deref for UART_ID_R {
    type Target = crate::FieldReader<u32, u32>;
    #[inline(always)]
    fn deref(&self) -> &Self::Target {
        &self.0
    }
}
#[doc = "Field `uart_id` writer - "]
pub struct UART_ID_W<'a> {
    w: &'a mut W,
}
impl<'a> UART_ID_W<'a> {
    #[doc = r"Writes raw bits to the field"]
    #[inline(always)]
    pub unsafe fn bits(self, value: u32) -> &'a mut W {
        self.w.bits = (self.w.bits & !0xffff_ffff) | ((value as u32) & 0xffff_ffff);
        self.w
    }
}
impl R {
    #[doc = "Bits 0:31"]
    #[inline(always)]
    pub fn uart_id(&self) -> UART_ID_R {
        UART_ID_R::new((self.bits & 0xffff_ffff) as u32)
    }
}
impl W {
    #[doc = "Bits 0:31"]
    #[inline(always)]
    pub fn uart_id(&mut self) -> UART_ID_W {
        UART_ID_W { w: self }
    }
    #[doc = "Writes raw bits to the register."]
    pub unsafe fn bits(&mut self, bits: u32) -> &mut Self {
        self.0.bits(bits);
        self
    }
}
#[doc = "UART_ID\n\nThis register you can [`read`](crate::generic::Reg::read), [`write_with_zero`](crate::generic::Reg::write_with_zero), [`reset`](crate::generic::Reg::reset), [`write`](crate::generic::Reg::write), [`modify`](crate::generic::Reg::modify). See [API](https://docs.rs/svd2rust/#read--modify--write-api).\n\nFor information about available fields see [uart_id](index.html) module"]
pub struct UART_ID_SPEC;
impl crate::RegisterSpec for UART_ID_SPEC {
    type Ux = u32;
}
#[doc = "`read()` method returns [uart_id::R](R) reader structure"]
impl crate::Readable for UART_ID_SPEC {
    type Reader = R;
}
#[doc = "`write(|w| ..)` method takes [uart_id::W](W) writer structure"]
impl crate::Writable for UART_ID_SPEC {
    type Writer = W;
}
#[doc = "`reset()` method sets UART_ID to value 0"]
impl crate::Resettable for UART_ID_SPEC {
    #[inline(always)]
    fn reset_value() -> Self::Ux {
        0
    }
}

==> esp8266-0.4.0.crate: esp8266-0.4.0/src/uart0/uart_id.rs <==
#[doc = "Register `UART_ID` reader"]
pub struct R(crate::R<UART_ID_SPEC>);
impl core::ops::Deref for R {
    type Target = crate::R<UART_ID_SPEC>;
    #[inline(always)]
    fn deref(&self) -> &Self::Target {
        &self.0
    }
}
impl From<crate::R<UART_ID_SPEC>> for R {
    #[inline(always)]
    fn from(reader: crate::R<UART_ID_SPEC>) -> Self {
        R(reader)
    }
}
#[doc = "Register `UART_ID` writer"]
pub struct W(crate::W<UART_ID_SPEC>);
impl core::ops::Deref for W {
    type Target = crate::W<UART_ID_SPEC>;
    #[inline(always)]
    fn deref(&self) -> &Self::Target {
        &self.0
    }
}
impl core::ops::DerefMut for W {
    #[inline(always)]
    fn deref_mut(&mut self) -> &mut Self::Target {
        &mut self.0
    }
}
impl From<crate::W<UART_ID_SPEC>> for W {
    #[inline(always)]
    fn from(writer: crate::W<UART_ID_SPEC>) -> Self {
        W(writer)
    }
}
#[doc = "Field `uart_id` reader - "]
pub struct UART_ID_R(crate::FieldReader<u32, u32>);
impl UART_ID_R {
    #[inline(always)]
    pub(crate) fn new(bits: u32) -> Self {
        UART_ID_R(crate::FieldReader::new(bits))
    }
}
impl core::ops::Deref for UART_ID_R {
    type Target = crate::FieldReader<u32, u32>;
    #[inline(always)]
    fn deref(&self) -> &Self::Target {
        &self.0
    }
}
#[doc = "Field `uart_id` writer - "]
pub struct UART_ID_W<'a> {
    w: &'a mut W,
}
impl<'a> UART_ID_W<'a> {
    #[doc = r"Writes raw bits to the field"]
    #[inline(always)]
    pub unsafe fn bits(self, value: u32) -> &'a mut W {
        self.w.bits = value as u32;
        self.w
    }
}
impl R {
    #[doc = "Bits 0:31"]
    #[inline(always)]
    pub fn uart_id(&self) -> UART_ID_R {
        UART_ID_R::new(self.bits as u32)
    }
}
impl W {
    #[doc = "Bits 0:31"]
    #[inline(always)]
    pub fn uart_id(&mut self) -> UART_ID_W {
        UART_ID_W { w: self }
    }
    #[doc = "Writes raw bits to the register."]
    #[inline(always)]
    pub unsafe fn bits(&mut self, bits: u32) -> &mut Self {
        self.0.bits(bits);
        self
    }
}
#[doc = "UART_ID\n\nThis register you can [`read`](crate::generic::Reg::read), [`write_with_zero`](crate::generic::Reg::write_with_zero), [`reset`](crate::generic::Reg::reset), [`write`](crate::generic::Reg::write), [`modify`](crate::generic::Reg::modify). See [API](https://docs.rs/svd2rust/#read--modify--write-api).\n\nFor information about available fields see [uart_id](index.html) module"]
pub struct UART_ID_SPEC;
impl crate::RegisterSpec for UART_ID_SPEC {
    type Ux = u32;
}
#[doc = "`read()` method returns [uart_id::R](R) reader structure"]
impl crate::Readable for UART_ID_SPEC {
    type Reader = R;
}
#[doc = "`write(|w| ..)` method takes [uart_id::W](W) writer structure"]
impl crate::Writable for UART_ID_SPEC {
    type Writer = W;
}
#[doc = "`reset()` method sets UART_ID to value 0"]
impl crate::Resettable for UART_ID_SPEC {
    #[inline(always)]
    fn reset_value() -> Self::Ux {
        0
    }
}
